<?php

add_action( 'woocommerce_shipping_init', 'furgefutar_gls_csomagpont_class', 0 );

function furgefutar_gls_csomagpont_class() {

    class Furgefutar_GLS_CsomagPont extends WC_Shipping_Method {

    	public function __construct( $instance_id = 0 ) {
    	      
    		$this->id = 'furgefutar_gls_csomagpont';
            $this->instance_id = absint( $instance_id );
    		$this->method_title = __( 'GLS CsomagPont', 'furgefutar' );
    		$this->method_description = __( 'Szállítás GLS CsomagPontra', 'furgefutar' );

            $this->enabled = "yes";
            
    
            $this->supports = array(
    			'shipping-zones',
    			'instance-settings',
    			'instance-settings-modal',
    		);
    
    		$this->init();
    
    	}
        
    	function init() {
    
    		$this->init_form_fields();
    		$this->init_settings();

            $this->title = $this->get_option( 'title' );
            $this->cost = $this->get_option( 'cost' );

    		add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
    	}
        
        public function init_form_fields() {
            
    		$this->instance_form_fields = array(
    			'title' => array(
    				'title'       => __( 'Elnevezés', 'furgefutar' ),
    				'type'        => 'text',
    				'description' => __( 'A vásárlók által a pénztárban látható elnevezés.', 'furgefutar' ),
    				'default'     => __( 'GLS CsomagPont', 'furgefutar' ),
    				'desc_tip'    => true,
    			),

                'cost' => array(
                    'title'       => __( 'Ár', 'furgefutar' ),
                    'type'        => 'text',
                    'description' => __( 'Szállítás költsége', 'furgefutar' ),
                    'desc_tip'    => true,
                ),
    		);
            
    	}
        
       	public function calculate_shipping( $package = array() ) {
    		$this->add_rate( array(
    			'label' 	 => $this->title,
    			'package'    => $package,
    			'cost'       => $this->cost,
    		) );
    	}
        
        public function admin_options() {
            
            if ( ! $this->instance_id ) {
                echo '<h3>';
                    echo $this->get_method_title();
                echo '</h3>';
            }
            
            echo'<p>';
                echo $this->get_method_description();
            echo'</p>';
    
            echo $this->get_admin_options_html();
        }
    
    }
       
}

/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_filter( 'woocommerce_shipping_methods', 'furgefutar_gls_csomagpont_szallitasi_mod' );

function furgefutar_gls_csomagpont_szallitasi_mod( $methods ) {

    $methods['furgefutar_gls_csomagpont'] = 'Furgefutar_GLS_CsomagPont';

    return $methods;
    
}

/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

function furgefutar_gls_csomagpont_adatok( $filter = '' ) {
    
    $furgefutar_gls_csomagpontok = array();
    
    //$url = 'https://api.allpacka.com/webservices/shipment/dropoffpoints/gls.ashx';
    
    $url = 'https://api.pactic.com/webservices/shipment/dropoffpoints/gls.ashx';
    
    if( extension_loaded( 'curl' ) ){

        $ch = curl_init();
    
        curl_setopt( $ch, CURLOPT_AUTOREFERER, TRUE );
        curl_setopt( $ch, CURLOPT_HEADER, FALSE );
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, TRUE );
        curl_setopt( $ch, CURLOPT_URL, $url );
        curl_setopt( $ch, CURLOPT_FOLLOWLOCATION, TRUE );    
        curl_setopt( $ch, CURLOPT_HTTPHEADER, array( 'Content-Type: application/json' ) );   
        
        $furgefutar_gls_csomagpontok_json = curl_exec( $ch );
        
        curl_close($ch);

    }
    else if( ini_get( 'allow_url_fopen' ) ){
       
        $furgefutar_gls_csomagpontok_json = file_get_contents( $url, false );
    
    }
    
    $furgefutar_gls_csomagpontok_tomb = json_decode( $furgefutar_gls_csomagpontok_json, true);
    
    foreach ( $furgefutar_gls_csomagpontok_tomb as $furgefutar_gls_csomagpont ){
        
        if( !empty( $filter ) ){
            
            //if( $filter == $furgefutar_gls_csomagpont->PostCode ){
            if( $filter == $furgefutar_gls_csomagpont['PostCode'] ){

                $furgefutar_gls_csomagpontok[] = $furgefutar_gls_csomagpont;
                
            }
            
        }
        else{
            
            $furgefutar_gls_csomagpontok[] = $furgefutar_gls_csomagpont;
            
        }

    }
    
    return json_encode( $furgefutar_gls_csomagpontok );

}

/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'wp_ajax_furgefutar_ajax_szallitasi_mod_ellenorzese', 'furgefutar_ajax_szallitasi_mod_ellenorzese' );
add_action( 'wp_ajax_nopriv_furgefutar_ajax_szallitasi_mod_ellenorzese', 'furgefutar_ajax_szallitasi_mod_ellenorzese' );

function furgefutar_ajax_szallitasi_mod_ellenorzese() {
    
    if ( isset($_REQUEST) ) {

         $furgefutar_kivalasztott_szallitasi_mod = furgefutar_kivalasztott_szallitasi_mod( 'array' );
         
         echo json_encode( 
            array(
               'nev' => $furgefutar_kivalasztott_szallitasi_mod['name'],
               'tipus' => get_option( 'furgefutar_gls_csomagpont_tipus' )
             ) 
         );

    }
    
    die();
}
 
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'wp_ajax_furgefutar_ajax_gls_csomagpontok', 'furgefutar_ajax_gls_csomagpontok' );
add_action( 'wp_ajax_nopriv_furgefutar_ajax_gls_csomagpontok', 'furgefutar_ajax_gls_csomagpontok' );

function furgefutar_ajax_gls_csomagpontok() {
        
    if ( isset($_REQUEST) ) {
        
        $furgefutar_gls_csomagpont_adatok_return = furgefutar_gls_csomagpont_adatok( $_REQUEST['filter'] );

        echo $furgefutar_gls_csomagpont_adatok_return;
        
    }
    
    die();
}


/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

function furgefutar_kivalasztott_szallitasi_mod( $type = 'array' ) {
        
     $chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
        
     list( $name, $id ) = explode( ':', $chosen_methods[0] );
     
     if( $type == 'array' ){
        
        return array(
           'name' => $name,
           'id' => $id
         );
     
     }
     else if( $type == 'name' ){
        
        return $name;
     
     }
     else if( $type == 'id' ){
       
        return $id;
     
     }  
    
}
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'woocommerce_checkout_update_order_meta', 'furgefutar_kivalasztott_gls_csomagpont_mentese' );

function furgefutar_kivalasztott_gls_csomagpont_mentese( $order_id ) {
        
	if ( ! empty( $_POST['furgefutar_kivalasztott_gls_csomagpont'] ) ) {
		
        update_post_meta( $order_id, '_furgefutar_kivalasztott_gls_csomagpont', str_replace( "'", '"', $_POST['furgefutar_kivalasztott_gls_csomagpont'] ) );
        
    }
    
}
    
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'woocommerce_checkout_process', 'furgefutar_kivalasztott_gls_csomagpont_ellenorzese' );

function furgefutar_kivalasztott_gls_csomagpont_ellenorzese() {
		
    if( furgefutar_kivalasztott_szallitasi_mod('name') == 'furgefutar_gls_csomagpont' ){

        if ( ! $_POST['furgefutar_kivalasztott_gls_csomagpont'] ){
            
	        wc_add_notice( __( 'Kérjük, válassz GLS CsomagPontot!', 'furgefutar' ), 'error' );
            
	    }
    
    }
    
}

/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'save_post', 'furgefutar_gls_csomagpont_modositas', 10, 3 );

function furgefutar_gls_csomagpont_modositas( $post_id, $post, $update ) {
    
    $order = wc_get_order( $post_id );

    $post_type = get_post_type( $post_id );

    if ( $post_type != 'shop_order' ){ 
        
        return;
        
    }

    if ( isset( $_POST['furgefutar_kivalasztott_gls_csomagpont'] ) ) {
        
        $furgefutar_kivalasztott_gls_csomagpont = get_post_meta( $post_id, '_furgefutar_kivalasztott_gls_csomagpont',true );
    
        if( empty( $furgefutar_kivalasztott_gls_csomagpont ) ) {
            
            if( !empty( $_POST['furgefutar_kivalasztott_gls_csomagpont'] ) ){
                
                $order->add_order_note( __( 'GLS CsomagPont hozzáadva.', 'furgefutar' ) );
                
            }
            
        }
        else{

            if( !empty( $_POST['furgefutar_kivalasztott_gls_csomagpont'] ) ){
                
                $order->add_order_note( __( 'GLS CsomagPont módosítva.', 'furgefutar' ) );
                
            }
            else{
                
                $order->add_order_note( __( 'GLS CsomagPont törölve.', 'furgefutar' ) );
                
            }

        }
        
      
        update_post_meta( $post_id, '_furgefutar_kivalasztott_gls_csomagpont', sanitize_text_field( $_POST['furgefutar_kivalasztott_gls_csomagpont'] ) );
   
    }

}
    
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'woocommerce_admin_order_data_after_shipping_address', 'furgefutar_gls_csomagpont_admin', 10, 1 );
     
function furgefutar_gls_csomagpont_admin( $order ){
    
    if( is_object( $order ) ) {
        $order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
    }
    else{
        $order_id = $order;
    }

	$furgefutar_kivalasztott_gls_csomagpont_json = get_post_meta( $order_id, '_furgefutar_kivalasztott_gls_csomagpont', true );
 
    echo '<div class="clear"></div>';
    
    echo '<br/>';
    
    echo '<div>';
    
        echo '<h3>';
        
            echo __( 'GLS CsomagPont', 'furgefutar' );
            
            echo '<span class="furgefutar_kivalasztott_gls_csomagpont_szerkesztes">';
                
                echo __( 'Szerkesztés', 'furgefutar' );
                
            echo '</span>';
            
        echo '</h3>';

        echo '<div id="furgefutar_gls_csomagpont_kontener">';
        
            echo '<div class="furgefutar_kivalasztott_gls_csomagpont_szerkesztes">';
            
                if( $furgefutar_kivalasztott_gls_csomagpont_json != '' ) {

                    echo '<span class="furgefutar_kivalasztott_gls_csomagpont_torles">';
                    
                        echo __( 'Kiválasztott GLS CsomagPont törlése', 'furgefutar' );
                        
                    echo '</span>';
                
                }
                
                echo '<p>';

                    echo '<div class="furgefutar_gls_csomagpont_filter_kontener">';
                    
                        echo '<input type="text" id="furgefutar_gls_csomagpont_filter" name="furgefutar_gls_csomagpont_filter" value="" placeholder="'.__( 'Keresés irányítószám alapján', 'furgefutar' ).'">';
                
                    echo '</div>';
                    
                    
                    echo '<div class="furgefutar_gls_csomagpont_lista_kontener">';
                    
                        echo '<div class="furgefutar_gls_csomagpont_lista_elemek">';

                        echo '</div>';  
                
                    echo '</div>';  
                
                echo '</p>';
            
            echo '</div>';  
            
            
            /**/
            
            echo '<p>';
            
                echo '<div class="furgefutar_gls_csomagpont_kivalasztott_kontener">';
                                                
                    echo '<div class="furgefutar_gls_csomagpont_kivalasztott_kontener_cim">';
                    
                        echo '<strong>';
                        
                            echo __( 'Választott GLS CsomagPont:', 'furgefutar' );
                        
                        echo '</strong>';
                        
                    echo '</div>';
                
                    if( $furgefutar_kivalasztott_gls_csomagpont_json != '' ) {
    	  
                        $furgefutar_kivalasztott_gls_csomagpont = json_decode( str_replace( "'", '"', $furgefutar_kivalasztott_gls_csomagpont_json ), true  );
                        
                        echo '<input type="text" id="furgefutar_kivalasztott_gls_csomagpont" name="furgefutar_kivalasztott_gls_csomagpont" furgefutar_gls_csomagpont_kod="'.$furgefutar_kivalasztott_gls_csomagpont['Code'].'" value="'.str_replace( '"', "'", json_encode( $furgefutar_kivalasztott_gls_csomagpont ) ).'">';
                
                        echo '<div class="furgefutar_gls_csomagpont_kivalasztott_kontener_adatok ">';
                        
                            echo $furgefutar_kivalasztott_gls_csomagpont['Name'];
                            
                            echo '<br/>';
                            
                            echo $furgefutar_kivalasztott_gls_csomagpont['PostCode'];
                            
                            echo '<br/>';
                            
                            echo $furgefutar_kivalasztott_gls_csomagpont['City'];
                            
                            echo '<br/>';
                            
                            echo $furgefutar_kivalasztott_gls_csomagpont['StreetAndBuildingNumber'];
                                
                        echo '</div>';
                
                        
                    }
                    else{
                        
                        echo '<input type="text" id="furgefutar_kivalasztott_gls_csomagpont" name="furgefutar_kivalasztott_gls_csomagpont" value="">';
                
                        echo '<div class="furgefutar_gls_csomagpont_kivalasztott_kontener_adatok furgefutar_gls_csomagpont_kivalasztott_kontener_adatok_ures">';
                            
                            echo __( 'még nincs kiválasztva', 'furgefutar' );
                        
                        echo '</div>';
        
                    }
                    
                echo '</div>';
            
            echo '</p>';

        echo '</div>';
        
    echo '</div>';

    

}

/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'woocommerce_email_after_order_table', 'furgefutar_kivalasztott_gls_csomagpont_emailben', 10, 1 );
        
function furgefutar_kivalasztott_gls_csomagpont_emailben( $order ){
    
    if( is_object( $order ) ) {
        $order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
    }
    else{
        $order_id = $order;
    }


	$furgefutar_kivalasztott_gls_csomagpont = get_post_meta( $order_id, '_furgefutar_kivalasztott_gls_csomagpont',true );
    
	if( !empty( $furgefutar_kivalasztott_gls_csomagpont ) ) {
	  
        $furgefutar_kivalasztott_gls_csomagpont = json_decode( str_replace( "'", '"', $furgefutar_kivalasztott_gls_csomagpont ), true );


        echo '<div>';
        
            echo '<h2>';
               
                echo __( 'Választott GLS CsomagPont', 'furgefutar' );
            
            echo '</h2>';
            
            echo '<div>';
               
                echo '<p>';
                   
                    echo $furgefutar_kivalasztott_gls_csomagpont['Name'];
                    
                    echo '<br/>';
                    
                    echo $furgefutar_kivalasztott_gls_csomagpont['PostCode'];
                    
                    echo '<br/>';
                    
                    echo $furgefutar_kivalasztott_gls_csomagpont['City'];
                    
                    echo '<br/>';
                    
                    echo $furgefutar_kivalasztott_gls_csomagpont['StreetAndBuildingNumber'];
               
                echo '</p>';
           
            echo '</div>';
            
            echo '<br/>';

        echo '</div>';

        
	}

}
    
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/

add_action( 'woocommerce_thankyou', 'furgefutar_kivalasztott_gls_csomagpont_rendelesnel' );

function furgefutar_kivalasztott_gls_csomagpont_rendelesnel( $order ){
    
    if( is_object( $order ) ) {
        $order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
    }
    else{
        $order_id = $order;
    }

	$furgefutar_kivalasztott_gls_csomagpont = get_post_meta( $order_id, '_furgefutar_kivalasztott_gls_csomagpont',true );
    
	if( !empty( $furgefutar_kivalasztott_gls_csomagpont ) ) {
	  
       $furgefutar_kivalasztott_gls_csomagpont = json_decode( str_replace( "'", '"', $furgefutar_kivalasztott_gls_csomagpont ), true );

        echo '<section class="woocommerce-columns">';

            echo '<h3 class="woocommerce-column__title">';
                
                echo __( 'Választott GLS CsomagPont', 'furgefutar' );
            
            echo '</h3>';
            
            echo '<address>';
     			
                echo $furgefutar_kivalasztott_gls_csomagpont['Name'];
                
                echo '<br/>';
                
                echo $furgefutar_kivalasztott_gls_csomagpont['PostCode'];
                
                echo '<br/>';
                
                echo $furgefutar_kivalasztott_gls_csomagpont['City'];
                
                echo '<br/>';
                
                echo $furgefutar_kivalasztott_gls_csomagpont['StreetAndBuildingNumber'];
            
            echo '</address>';

        echo '</section>';
        
	}

}
    
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/



/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/


        
/**********************************************************************************************************************************************************************/
/**********************************************************************************************************************************************************************/



?>